<?php
/**
 * @file
 * XML parser for Rijksvideoserver files.
 */

/**
 * XML parser for Rijksvideoserver files.
 */
function _rijksvideo_parse_xml($url) {
  $result_xmlstr = drupal_http_request($url);
  $xmlstr = isset($result_xmlstr->data) ? $result_xmlstr->data : FALSE;
  $result = new SimpleXMLElement($xmlstr);

  // Find out which service this xml belongs to
  if (count($result->creationDate)) {
    // Mediatheek service (host: www.rovid.nl)

    $rijksvideo['duration'] = isset($result->duration) ? trim($result->duration) : NULL;  // not available yet!
    $rijksvideo['resolution'] = isset($result->resolution) ? trim($result->resolution) : NULL; // not available yet!
    $rijksvideo['language'] = isset($result->language) ? trim($result->language) : NULL; // not available yet!
    $rijksvideo['date'] = isset($result->publicationDate) ? trim($result->publicationDate) : NULL;

    foreach ($result->files->children() as $file) {
      $url = (string)$file;
      // Get attributes from file
      $attributes = (array)$file->attributes();
      $attributes = $attributes['@attributes'];

      switch ($attributes['type']) {
        case 'still_m':
          $rijksvideo['thumbnail'] = $url;
          break;

        case 'subtitle_srt':
          $rijksvideo['caption'] = $url;
          break;

        case 'text':
          $rijksvideo['transcription'] = _rijksvideo_fetch_transcription($url);
          break;

        case 'audio_mp3':
          $rijksvideo['audio'] = $url;
          break;

        // Video files
        case 'web_webm':
          $rijksvideo['video']['webm']['url'] = $url;
          $rijksvideo['video']['webm']['size'] = parse_size($attributes['size']);
          $rijksvideo['video']['webm']['type'] = 'webm';
          break;

        case 'web_mp4':
          $rijksvideo['video']['mp4']['url'] = $url;
          $rijksvideo['video']['mp4']['size'] = parse_size($attributes['size']);
          $rijksvideo['video']['mp4']['type'] = 'mp4';
          break;

        case 'web_wmv':
          $rijksvideo['video']['wmv']['url'] = $url;
          $rijksvideo['video']['wmv']['size'] = parse_size($attributes['size']);
          $rijksvideo['video']['wmv']['type'] = 'wmv';
          break;

        case 'web_flv':
          $rijksvideo['video']['flv']['url'] = $url;
          $rijksvideo['video']['flv']['size'] = parse_size($attributes['size']);
          $rijksvideo['video']['flv']['type'] = 'flv';
          break;

        case 'web_hd':
          $rijksvideo['video']['mp4HR']['url'] = $url;
          $rijksvideo['video']['mp4HR']['size'] = parse_size($attributes['size']);
          $rijksvideo['video']['mp4HR']['type'] = 'mp4HR';
          break;
      }
    }
  }
  elseif (count($result->channel->lastBuildDate)) {
    // Mediabank service (host: server.rijksoverheidsvideo.nl)

    foreach ($result->children() as $chapter) {
      foreach ($chapter->children() as $child) {
        if (count($child->children('overheidsVideo', TRUE))) {

          // Get video info using "overheidsVideo" namespace
          $video_info = $child->children('overheidsVideo', TRUE);

          $rijksvideo['thumbnail'] = isset($video_info->foto) ? trim($video_info->foto) : NULL;
          $rijksvideo['caption'] = isset($video_info->caption) ? trim($video_info->caption) : NULL;
          $rijksvideo['audio'] = isset($video_info->audio) ? trim($video_info->audio) : NULL;
          $rijksvideo['duration'] = isset($video_info->duration) ? trim($video_info->duration) : NULL;
          $rijksvideo['resolution'] = isset($video_info->resolution) ? trim($video_info->resolution) : NULL;
          $rijksvideo['language'] = isset($video_info->language) ? trim($video_info->language) : NULL;
          $rijksvideo['date'] = isset($video_info->pubDate) ? trim($video_info->pubDate) : NULL;
          $rijksvideo['transcription'] = isset($video_info->transcript) ? trim($video_info->transcript) : NULL;

          $rijksvideo['transcription'] = _rijksvideo_fetch_transcription($rijksvideo['transcription']);

          foreach ($video_info->video as $video) {
            $url = (string)$video;
            // Get attributes from video
            $attributes = (array)$video->attributes();
            $attributes = $attributes['@attributes'];
            $rijksvideo['video'][$attributes['type']] = $attributes;
            $rijksvideo['video'][$attributes['type']]['size'] = parse_size($attributes['size']);
            $rijksvideo['video'][$attributes['type']]['url'] = $url;
          }
        }
      }
    }
  }

  return $rijksvideo;
}

/*
 * Fetch transcription text from remote URL
 */
function _rijksvideo_fetch_transcription($url) {
  if (!empty($url)) {
    $result_transcription = drupal_http_request(trim($url));
    $transcription = isset($result_transcription->data) ? $result_transcription->data : FALSE;
    if (empty($transcription) || $transcription == 0) {
      $transcription = '';
    }
    return $transcription;
  }
}